@@ -44,6 +44,7 @@ class xml_files(devede_executor.executor):
 		self.structure=structure
 		self.AC3_fix=global_vars["AC3_fix"]
 		self.use_ffmpeg=global_vars["use_ffmpeg"]
+		self.use_ffmpeg_menu=global_vars["use_ffmpeg_menu"]
 		self.with_menu=global_vars["with_menu"]
 		if (len(structure)==1) and (len(structure[0])==2) and (not self.with_menu):
 			self.onlyone=True
@@ -875,11 +876,13 @@ class xml_files(devede_executor.executor):
 		self.mplexed=False
 		command_var=[]
 		command_var.append("ffmpeg")
+		#command_var.append("avconv")
 	
 		currentfile=self.filefolder+self.filename+"_menu_"+str(counter)+".mpg"
 	
 		audio=self.menu_sound
-		command_var.append("-loop_input")
+		command_var.append("-loop")
+		command_var.append("1")
 		
 		command_var.append("-f")
 		command_var.append("image2")
@@ -903,22 +906,28 @@ class xml_files(devede_executor.executor):
 			command_var.append("720x480")
 		command_var.append("-g")
 		command_var.append("12")
-		command_var.append("-ac")
-		command_var.append("2")
-		command_var.append("-trellis")
-		command_var.append("1")
-		command_var.append("-mbd")
-		command_var.append("2")
+#		command_var.append("-bf")
+#		command_var.append("2")
+#		command_var.append("-strict")
+#		command_var.append("1")
+#		command_var.append("-ac")
+#		command_var.append("2")
+#		command_var.append("-trellis")
+#		command_var.append("1")
+#		command_var.append("-mbd")
+#		command_var.append("2")
 		command_var.append("-b")
-		command_var.append("1000000")
+		command_var.append("2500k")
 		command_var.append("-ab")
-		command_var.append("128000")
+		command_var.append("192000")
+#		command_var.append("-maxrate")
+#		command_var.append("4000k")
+#		command_var.append("-minrate")
+#		command_var.append("2200k")
 		command_var.append("-aspect")
 		command_var.append("4:3")
 
-
 		#audio="/home/raster/Escritorio/lazy.mp3"
-
 		
 		command_var.append(currentfile)
 		origDir=os.getcwd()
@@ -931,7 +940,7 @@ class xml_files(devede_executor.executor):
 	
 		print "Creating menus"
 	
-		if (self.use_ffmpeg):
+		if (self.use_ffmpeg_menu):
 			self.create_menu_mpg_ffmpeg(counter)
 			return
 	
@@ -981,13 +990,13 @@ class xml_files(devede_executor.executor):
 		else:
 			lavcopts=""
 		lavcopts+="vcodec=mpeg2video:sc_threshold=1000000000:cgop:trell:mbd=2:vstrict=0:"
-		lavcopts+="vrc_maxrate=7000:vrc_buf_size=1835:vbitrate=1000:keyint=12:"
+		lavcopts+="vrc_maxrate=4000:vrc_buf_size=1835:vbitrate=2500:keyint=12:"
 		lavcopts+="acodec="
 		if self.AC3_fix:
 			lavcopts+="ac3_fixed"
 		else:
 			lavcopts+="ac3"
-		lavcopts+=":abitrate=128:aspect="+wide
+		lavcopts+=":abitrate=192:aspect="+wide
 		command_var.append(lavcopts)
 		command_var.append("-o")
 		command_var.append(currentfile)
@@ -1019,19 +1028,19 @@ class xml_files(devede_executor.executor):
 			comando=["spumux.exe"]
 			# The -i -o is with a custom patched version of
 			# dvdauthor.  Best and easiest way of making it work
-			comando.append(self.filefolder+self.filename+"_menu_"+str(counter)+".xml")
+			comando.append(os.path.join(self.filefolder,self.filename+"_menu_"+str(counter)+".xml"))
 			comando.append("-i")
-			comando.append(self.filefolder+self.filename+"_menu_"+str(counter)+".mpg")
+			comando.append(os.path.join(self.filefolder,self.filename+"_menu_"+str(counter)+".mpg"))
 			comando.append("-o")
-			comando.append(self.filefolder+self.filename+"_menu2_"+str(counter)+".mpg")
+			comando.append(os.path.join(self.filefolder,self.filename+"_menu2_"+str(counter)+".mpg"))
 			self.launch_program(comando)
 		else:
 			comando="spumux"
 			
-			comando+=' "' +self.filefolder+self.filename+'_menu_'+str(counter)+'.xml"'
+			comando+=' "' +os.path.join(self.filefolder,self.filename+'_menu_'+str(counter)+'.xml"')
 
 			print "Launch: "+comando
-			self.launch_shell(comando,stdinout=[self.filefolder+self.filename+"_menu_"+str(counter)+".mpg",self.filefolder+self.filename+"_menu2_"+str(counter)+".mpg"])
+			self.launch_shell(comando,stdinout=[os.path.join(self.filefolder,self.filename+"_menu_"+str(counter)+".mpg"),os.path.join(self.filefolder,self.filename+"_menu2_"+str(counter)+".mpg")])
 
 
 	def end_process(self,eraser,erase_temporary_files):
